/* miktex/Core/Help.h:                                  -*- C++ -*-

   Copyright (C) 1996-2020 Christian Schenk

   This file is part of the MiKTeX Core Library.

   The MiKTeX Core Library is free software; you can redistribute it
   and/or modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2, or
   (at your option) any later version.

   The MiKTeX Core Library is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty
   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with the MiKTeX Core Library; if not, write to the Free
   Software Foundation, 59 Temple Place - Suite 330, Boston, MA
   02111-1307, USA. */

#pragma once

#if !defined(D1CA06364EBEA84ABFAADFFE2DB60271)
#define D1CA06364EBEA84ABFAADFFE2DB60271

#define MIKTEXHELP_MTPRINT 100
#define MIKTEXHELP_TEX 101
#define MIKTEXHELP_BIBTEX 102
#define MIKTEXHELP_DVICOPY 103
#define MIKTEXHELP_DVIPS 104
#define MIKTEXHELP_XETEX 105
#define MIKTEXHELP_FINDTEXMF 106
#define MIKTEXHELP_GFTODVI 107
#define MIKTEXHELP_INITEXMF 108
#define MIKTEXHELP_MF 109
#define MIKTEXHELP_MPOST 110
/*unused 111*/
#define MIKTEXHELP_PDFTEX 112
#define MIKTEXHELP_TEXIFY 113
#define MIKTEXHELP_MPMCON 114

#endif
